#!/usr/bin/python

import csv
from statistics import mean
import sys
import getopt


def main(argv):
    inputfile = ''
    outputfile = ''
    try:
        opts, args = getopt.getopt(argv, "hi:o:", ["ifile=", "ofile="])
    except getopt.GetoptError:
        print('test.py -i <inputfile> -o <outputfile>')
        sys.exit(2)
    for opt, arg in opts:
        if opt == '-h':
            print('test.py -i <inputfile> -o <outputfile>')
            sys.exit()
        elif opt in ("-i", "--ifile"):
            inputfile = arg
        elif opt in ("-o", "--ofile"):
            outputfile = arg

    temperatures = {}
    humidities = {}
    with open(inputfile, mode='r') as f:
        reader = csv.reader(f, delimiter=';')  # dialect=csv.excel_tab?
        for n, row in enumerate(reader):
            if not n:
                # Skip header row (n = 0).
                continue
            t, temperature, humidity = row
            if t not in temperatures:
                temperatures[t] = list()
                humidities[t] = list()
            temperatures[t].append(float(temperature))
            humidities[t].append(float(humidity))
    
    with open(outputfile, mode='w') as output:
        writer = csv.writer(output,delimiter=';')
        for t in sorted(temperatures):
            writer.writerow([t,mean(temperatures[t]),mean(humidities[t])])
        output.flush()
        output.close()


if __name__ == "__main__":
    main(sys.argv[1:])